"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestSessionManager = void 0;
const TestSession_1 = require("./TestSession");
const utils_1 = require("./utils");
class TestSessionManager {
    constructor() {
        this.sessions = new Map();
        this.sessionsByBrowser = new Map();
        this.sessionsByTestFile = new Map();
        this.finishedSessionsByTestFile = new Map();
        this.scheduledSessions = new Set();
        this.initializingSessions = new Set();
        this.runningSessions = new Set();
        this.startedSessions = new Set();
        this.finishedSessions = new Set();
        this.passedSessions = new Map();
        this.failedSessions = new Map();
    }
    updateSession(newSession) {
        this.sessions.set(newSession.id, newSession);
        utils_1.replaceOrAddInMappedArray(this.sessionsByBrowser, newSession.browserName, newSession);
        utils_1.replaceOrAddInMappedArray(this.sessionsByTestFile, newSession.testFile, newSession);
        if (newSession.status === TestSession_1.SessionStatuses.FINISHED) {
            utils_1.replaceOrAddInMappedArray(this.finishedSessionsByTestFile, newSession.testFile, newSession);
        }
        else {
            utils_1.removeFromMappedArray(this.finishedSessionsByTestFile, newSession.testFile, newSession);
        }
        if (newSession.status === TestSession_1.SessionStatuses.SCHEDULED) {
            this.scheduledSessions.add(newSession.id);
            this.initializingSessions.delete(newSession.id);
            this.startedSessions.delete(newSession.id);
            this.runningSessions.delete(newSession.id);
            this.finishedSessions.delete(newSession.id);
        }
        else if (newSession.status === TestSession_1.SessionStatuses.INITIALIZING) {
            this.scheduledSessions.delete(newSession.id);
            this.initializingSessions.add(newSession.id);
            this.startedSessions.delete(newSession.id);
            this.runningSessions.add(newSession.id);
            this.finishedSessions.delete(newSession.id);
        }
        else if (newSession.status === TestSession_1.SessionStatuses.STARTED) {
            this.scheduledSessions.delete(newSession.id);
            this.initializingSessions.delete(newSession.id);
            this.startedSessions.add(newSession.id);
            this.runningSessions.add(newSession.id);
            this.finishedSessions.delete(newSession.id);
        }
        else if (newSession.status === TestSession_1.SessionStatuses.FINISHED) {
            this.scheduledSessions.delete(newSession.id);
            this.initializingSessions.delete(newSession.id);
            this.startedSessions.delete(newSession.id);
            this.runningSessions.delete(newSession.id);
            this.finishedSessions.add(newSession.id);
        }
        if (newSession.status === TestSession_1.SessionStatuses.FINISHED) {
            if (newSession.result.passed) {
                this.passedSessions.set(newSession.id, newSession);
                this.failedSessions.delete(newSession.id);
            }
            else {
                this.passedSessions.delete(newSession.id);
                this.failedSessions.set(newSession.id, newSession);
            }
        }
        else {
            this.passedSessions.delete(newSession.id);
            this.failedSessions.delete(newSession.id);
        }
    }
}
exports.TestSessionManager = TestSessionManager;
//# sourceMappingURL=TestSessionManager.js.map