"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestReporter = void 0;
const getTestProgressReport_1 = require("./getTestProgressReport");
const getSessionErrorsReport_1 = require("./getSessionErrorsReport");
const TestSession_1 = require("../TestSession");
const getTestFileReport_1 = require("./getTestFileReport");
const getTestCoverageReport_1 = require("./getTestCoverageReport");
class TestReporter {
    constructor(terminal) {
        this.terminal = terminal;
        this.reportedFilesByTestRun = new Map();
    }
    reportTestRunStart(testRun, allBrowserNames, favoriteBrowser, sessionsByTestFile, scheduledSessions, runningSessions, serverAddress) {
        if (testRun !== 0) {
            // Restart terminal
            this.terminal.restart();
        }
        // Log results of test files that are not being re-run
        for (const [testFile, sessions] of sessionsByTestFile) {
            if (!sessions.some((s) => scheduledSessions.has(s.id) || runningSessions.has(s.id))) {
                this.reportTestFileResults(testRun, testFile, allBrowserNames, favoriteBrowser, sessions, serverAddress);
            }
        }
    }
    reportTestCoverage(coverageData, passedCoverage, coverageThreshold) {
        this.terminal.logStatic(getTestCoverageReport_1.getTestCoverageReport(coverageData, passedCoverage, coverageThreshold));
    }
    reportTestFileResults(testRun, testFile, allBrowserNames, favoriteBrowser, sessionsForTestFile, serverAddress) {
        const allFinished = sessionsForTestFile.every((s) => s.status === TestSession_1.SessionStatuses.FINISHED);
        if (!allFinished) {
            return;
        }
        let reportedFiles = this.reportedFilesByTestRun.get(testRun);
        if (!reportedFiles) {
            reportedFiles = new Set();
            this.reportedFilesByTestRun.set(testRun, reportedFiles);
        }
        if (!(reportedFiles === null || reportedFiles === void 0 ? void 0 : reportedFiles.has(testFile))) {
            reportedFiles.add(testFile);
            this.terminal.logStatic(getTestFileReport_1.getTestFileReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, sessionsForTestFile));
        }
    }
    reportSessionErrors(failedSessions, serverAddress) {
        const sessionErrorsReport = getSessionErrorsReport_1.getSessionErrorsReport(failedSessions, serverAddress);
        this.terminal.logStatic(sessionErrorsReport);
    }
    reportTestProgress(config, args) {
        const dynamicEntries = getTestProgressReport_1.getTestProgressReport(config, args);
        dynamicEntries.push(`\nPress D to debug in the browser.`);
        this.terminal.logDynamic(dynamicEntries);
    }
    reportEnd() {
        this.terminal.stop();
    }
}
exports.TestReporter = TestReporter;
//# sourceMappingURL=TestReporter.js.map