"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFileErrorsReport = exports.renderError = void 0;
const chalk_1 = __importDefault(require("chalk"));
const diff = __importStar(require("diff"));
const REGEXP_ERROR_LOCATION_BRACKETS = /\((.*)\)/;
function renderDiff(actual, expected) {
    function cleanUp(line) {
        if (line[0] === '+') {
            return chalk_1.default.green(line);
        }
        if (line[0] === '-') {
            return chalk_1.default.red(line);
        }
        if (line.match(/\@\@/)) {
            return null;
        }
        if (line.match(/\\ No newline/)) {
            return null;
        }
        return line;
    }
    const diffMsg = diff
        .createPatch('string', actual, expected)
        .split('\n')
        .splice(4)
        .map(cleanUp)
        .filter((l) => !!l)
        .join('\n');
    return `${chalk_1.default.green('+ expected')} ${chalk_1.default.red('- actual')}\n\n${diffMsg}`;
}
function findFirstWord(line) {
    for (const maybeWord of line.split(' ')) {
        if (maybeWord !== '') {
            return maybeWord;
        }
    }
}
function getErrorLocation(err, serverAddress) {
    if (!err.stack) {
        return undefined;
    }
    for (const line of err.stack.split('\n')) {
        // firefox & safari
        if (line.includes('@')) {
            return line.split('@')[1];
        }
        // chromium
        if (findFirstWord(line) === 'at') {
            const match = line.match(REGEXP_ERROR_LOCATION_BRACKETS);
            if (match && match.length >= 2) {
                return match[1];
            }
        }
    }
}
function renderError(err, serverAddress) {
    const errorLocation = getErrorLocation(err, serverAddress);
    let errorString = errorLocation != null ? `at: ${chalk_1.default.underline(errorLocation)}\n` : '';
    if (typeof err.expected === 'string' && typeof err.actual === 'string') {
        errorString += `error: ${chalk_1.default.red(err.message)}\n${renderDiff(err.actual, err.expected)}`;
    }
    else {
        errorString +=
            errorLocation || !err.stack ? `error: ${chalk_1.default.red(err.message)}` : `${chalk_1.default.red(err.stack)}`;
    }
    return errorString;
}
exports.renderError = renderError;
function createFailedOnBrowsers(allBrowserNames, failedBrowsers) {
    if (allBrowserNames.length === 1 || failedBrowsers.length === allBrowserNames.length) {
        return '';
    }
    const browserString = failedBrowsers.length === 1
        ? failedBrowsers[0]
        : failedBrowsers.slice(0, -1).join(', ') + ' and ' + failedBrowsers.slice(-1);
    return ` (failed on ${browserString})`;
}
function getFileErrorsReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, failedSessions) {
    var _a;
    const entries = [];
    const sessionsThatFailedToImport = failedSessions.filter((s) => s.result.failedImports.some((imp) => imp.file === testFile));
    if (sessionsThatFailedToImport.length > 0) {
        const session = sessionsThatFailedToImport.find((s) => s.browserName === favoriteBrowser) ||
            sessionsThatFailedToImport[0];
        const failedImport = session.result.failedImports.find((i) => i.file === testFile);
        const failedBrowsers = sessionsThatFailedToImport.map((s) => s.browserName);
        const failedOn = createFailedOnBrowsers(allBrowserNames, failedBrowsers);
        entries.push({ text: `Failed to load test file${failedOn}`, indent: 2 });
        entries.push({ text: renderError(failedImport.error, serverAddress), indent: 4 });
    }
    const testErrorsPerBrowser = new Map();
    for (const session of failedSessions) {
        for (const test of session.result.tests) {
            if (test.error) {
                let testErrorsForBrowser = testErrorsPerBrowser.get(test.name);
                if (!testErrorsForBrowser) {
                    testErrorsForBrowser = new Map();
                    testErrorsPerBrowser.set(test.name, testErrorsForBrowser);
                }
                testErrorsForBrowser.set(session.browserName, test.error);
            }
        }
    }
    if (testErrorsPerBrowser.size > 0) {
        for (const [name, errorsForBrowser] of testErrorsPerBrowser) {
            const failedBrowsers = Array.from(errorsForBrowser.keys());
            const favoriteError = (_a = errorsForBrowser.get(favoriteBrowser)) !== null && _a !== void 0 ? _a : errorsForBrowser.get(failedBrowsers[0]);
            const failedOn = createFailedOnBrowsers(allBrowserNames, failedBrowsers);
            entries.push({ text: `${name}${failedOn}`, indent: 2 });
            entries.push({ text: renderError(favoriteError, serverAddress), indent: 4 });
        }
    }
    return entries;
}
exports.getFileErrorsReport = getFileErrorsReport;
//# sourceMappingURL=getFileErrorsReport.js.map