const PARAM_SESSION_ID = 'wtr-session-id';
const PARAM_DEBUG = 'wtr-debug';
const pendingLogs = new Set();
const sessionId = new URL(window.location.href).searchParams.get(PARAM_SESSION_ID);
const debug = new URL(window.location.href).searchParams.get(PARAM_DEBUG) === 'true';
if (typeof sessionId !== 'string') {
    throw new Error(`Could not find any session id query parameter.`);
}
function postJSON(url, body) {
    return fetch(url, {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(body),
    });
}
const logs = [];
function stringify(obj) {
    try {
        return JSON.stringify(obj);
    }
    catch (error) {
        // some objects can't be stringified, such as circular objects
        return obj;
    }
}
export function captureConsoleOutput() {
    for (const level of ['log', 'error', 'debug', 'warn']) {
        const original = console[level];
        console[level] = (...args) => {
            logs.push(args.map((a) => (typeof a === 'object' ? stringify(a) : a)).join(' '));
            original.apply(console, args);
        };
    }
}
export function logUncaughtErrors() {
    window.addEventListener('error', (e) => {
        console.error(`Uncaught error: ${e.error.stack}`);
    });
    window.addEventListener('unhandledrejection', (e) => {
        e.promise.catch((error) => {
            console.error(`Unhandled rejection: ${error.stack}`);
        });
    });
}
export async function getConfig() {
    try {
        const response = await fetch(`/wtr/${sessionId}/config`);
        return Object.assign(Object.assign({}, (await response.json())), { debug });
    }
    catch (error) {
        await error({ message: 'Failed to fetch session config', stack: error.stack });
        throw error;
    }
}
export function error(error) {
    return sessionFinished({
        passed: false,
        error,
        failedImports: [],
        tests: [],
    });
}
export async function sessionStarted() {
    await fetch(`/wtr/${sessionId}/session-started`, { method: 'POST' });
}
export async function sessionFinished(result) {
    const sessionResult = Object.assign({ logs, testCoverage: window.__coverage__ }, result);
    await Promise.all(Array.from(pendingLogs)).catch(() => { });
    await postJSON(`/wtr/${sessionId}/session-finished`, sessionResult);
}
//# sourceMappingURL=runtime.js.map