"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTestSessions = exports.removeFromMappedArray = exports.replaceOrAddInMappedArray = exports.arrayReplaceOrAddById = void 0;
const uuid_1 = require("uuid");
const TestSession_1 = require("./TestSession");
function arrayReplaceOrAddById(array, replacedItem) {
    return array.filter((i) => i.id !== replacedItem.id).concat(replacedItem);
}
exports.arrayReplaceOrAddById = arrayReplaceOrAddById;
function replaceOrAddInMappedArray(map, key, replacedItem) {
    let array = map.get(key);
    if (!array) {
        array = [replacedItem];
    }
    else {
        array = arrayReplaceOrAddById(array, replacedItem);
    }
    map.set(key, array);
}
exports.replaceOrAddInMappedArray = replaceOrAddInMappedArray;
function removeFromMappedArray(map, key, replacedItem) {
    let array = map.get(key);
    if (array) {
        array = array.filter((i) => i.id !== replacedItem.id);
        map.set(key, array);
    }
}
exports.removeFromMappedArray = removeFromMappedArray;
function createTestSessions(browserNames, testFiles) {
    const sessions = new Map();
    // when running each test files in a separate tab, we group tests by file
    for (const testFile of testFiles) {
        const group = testFile;
        const sessionsForFile = browserNames.map((browserName) => ({
            id: uuid_1.v4(),
            testRun: -1,
            group,
            browserName,
            status: TestSession_1.SessionStatuses.SCHEDULED,
            testFile,
        }));
        for (const session of sessionsForFile) {
            sessions.set(session.id, session);
        }
    }
    return sessions;
}
exports.createTestSessions = createTestSessions;
//# sourceMappingURL=utils.js.map