"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEsDevServer = void 0;
const es_dev_server_1 = require("es-dev-server");
const deepmerge_1 = __importDefault(require("deepmerge"));
const co_body_1 = __importDefault(require("co-body"));
const chokidar_1 = __importDefault(require("chokidar"));
const dependencyGraphMiddleware_1 = require("./dependencyGraphMiddleware");
const createTestPage_1 = require("./createTestPage");
const createDebugPage_1 = require("./createDebugPage");
function createEsDevServer(devServerConfig = {}) {
    let server;
    return {
        async start({ config, testFiles, sessions, onSessionStarted, onSessionFinished, onRerunSessions: originalOnRerunSessions, }) {
            var _a;
            const request404sPerSession = new Map();
            const testFrameworkImport = process.env.LOCAL_TESTING
                ? config.testFrameworkImport.replace('web-test-runner', '.')
                : config.testFrameworkImport;
            function onRerunSessions(sessionIds) {
                for (const id of sessionIds) {
                    // clear stored 404s on reload
                    request404sPerSession.delete(id);
                }
                originalOnRerunSessions(sessionIds);
            }
            function onRequest404(sessionId, url) {
                let request404sForSession = request404sPerSession.get(sessionId);
                if (!request404sForSession) {
                    request404sForSession = new Set();
                    request404sPerSession.set(sessionId, request404sForSession);
                }
                request404sForSession.add(url);
            }
            const fileWatcher = chokidar_1.default.watch([]);
            const serverConfig = es_dev_server_1.createConfig(deepmerge_1.default({
                port: config.port,
                nodeResolve: true,
                debug: false,
                logStartup: false,
                logCompileErrors: false,
                babelConfig: config.coverage
                    ? {
                        plugins: [
                            [
                                require.resolve('babel-plugin-istanbul'),
                                {
                                    exclude: typeof config.coverage === 'boolean'
                                        ? [testFiles]
                                        : [...testFiles, ...((_a = config.coverage.exclude) !== null && _a !== void 0 ? _a : [])],
                                },
                            ],
                        ],
                    }
                    : undefined,
                middlewares: [
                    async function middleware(ctx, next) {
                        var _a;
                        if (ctx.path.startsWith('/wtr/')) {
                            const [, , sessionId, command] = ctx.path.split('/');
                            if (!sessionId)
                                return next();
                            if (!command)
                                return next();
                            const session = sessions.get(sessionId);
                            if (!session) {
                                ctx.status = 400;
                                ctx.body = `Session id ${sessionId} not found`;
                                console.error(ctx.body);
                                return;
                            }
                            if (command === 'config') {
                                ctx.body = JSON.stringify(Object.assign(Object.assign({}, session), { watch: !!config.watch }));
                                return;
                            }
                            // TODO: Handle race conditions for these requests
                            if (command === 'session-started') {
                                ctx.status = 200;
                                onSessionStarted(sessionId);
                                return;
                            }
                            if (command === 'session-finished') {
                                ctx.status = 200;
                                const result = (await co_body_1.default.json(ctx));
                                onSessionFinished(sessionId, Object.assign(Object.assign({}, result), { request404s: (_a = request404sPerSession.get(sessionId)) !== null && _a !== void 0 ? _a : new Set() }));
                                return;
                            }
                        }
                        return next();
                    },
                    dependencyGraphMiddleware_1.dependencyGraphMiddleware({
                        // TODO: Configurable cwd?
                        rootDir: process.cwd(),
                        fileWatcher,
                        onRequest404,
                        onRerunSessions,
                    }),
                ],
                plugins: [
                    {
                        serve(context) {
                            if (context.path === '/') {
                                return {
                                    type: 'html',
                                    body: config.testRunnerHtml
                                        ? config.testRunnerHtml(config)
                                        : createTestPage_1.createTestPage(context, testFrameworkImport),
                                };
                            }
                            if (context.path === '/debug/') {
                                return {
                                    type: 'html',
                                    body: createDebugPage_1.createDebugPage(Array.from(sessions.values())),
                                };
                            }
                        },
                    },
                ],
            }, devServerConfig));
            ({ server } = await es_dev_server_1.startServer(serverConfig, fileWatcher));
        },
        async stop() {
            await (server === null || server === void 0 ? void 0 : server.close());
        },
    };
}
exports.createEsDevServer = createEsDevServer;
//# sourceMappingURL=es-dev-server.js.map